@@ -1,12 +1,12 @@
+import dataclasses
 from typing import get_args
 import warnings
 
 from django.conf import settings as django_settings
-from django.utils.module_loading import import_string
 
 from gqlauth.settings_type import DjangoSetting, GqlAuthSettings, ImportString
 
-gqlauth_settings: GqlAuthSettings = None
+gqlauth_settings: GqlAuthSettings
 
 if user_settings := getattr(django_settings, "GQL_AUTH", False):
     if isinstance(user_settings, GqlAuthSettings):
@@ -24,11 +24,13 @@ else:
 
 defaults = GqlAuthSettings()
 # retain django_settings
-for name, setting in gqlauth_settings.__dataclass_fields__.items():
+for field in dataclasses.fields(gqlauth_settings):
+    name = field.name
     value = getattr(gqlauth_settings, name)
-    if setting.type is DjangoSetting and value is getattr(defaults, name):
+    if DjangoSetting in get_args(field.type) and value is getattr(defaults, name):
         setattr(gqlauth_settings, name, value())
-    elif ImportString in get_args(setting.type) and isinstance(value, str):
-        setattr(gqlauth_settings, name, import_string(value))
+    elif (f_type := getattr(field.type, "__origin__", None)) and f_type is ImportString:
+        assert isinstance(value, ImportString)
+        setattr(gqlauth_settings, name, value.preform_import())
 
 del defaults
